@@ -5,6 +5,7 @@ from ._httpdomain_old import HttpdomainOldRenderer
 from ._httpdomain import HttpdomainRenderer
 from ._model import ModelRenderer
 from ._toc import TocRenderer
+from ._description import DescriptionRenderer
 
 
 __all__ = [
@@ -13,4 +14,5 @@ __all__ = [
     "HttpdomainRenderer",
     "ModelRenderer",
     "TocRenderer",
+    "DescriptionRenderer",
 ]
